==> io.wcm.testing.aem-mock.core-5.1.2-sources.jar: io/wcm/testing/mock/aem/MockContentFragment_ContentVariation_Structured.java <==
/*
 * #%L
 * wcm.io
 * %%
 * Copyright (C) 2019 wcm.io
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package io.wcm.testing.mock.aem;

import java.util.Calendar;

import org.apache.sling.api.resource.ModifiableValueMap;
import org.jetbrains.annotations.NotNull;

import com.adobe.cq.dam.cfm.ContentFragmentException;
import com.adobe.cq.dam.cfm.ContentVariation;
import com.adobe.cq.dam.cfm.FragmentData;
import com.adobe.cq.dam.cfm.SyncStatus;
import com.adobe.cq.dam.cfm.VariationDef;

/**
 * Mock implementation of {@link ContentVariation}.
 */
class MockContentFragment_ContentVariation_Structured extends MockContentFragment_Versionable implements ContentVariation {

  private final VariationDef variationDef;
  private final String structuredDataKey;
  private final ModifiableValueMap structuredDataProps;

  MockContentFragment_ContentVariation_Structured(VariationDef variationDef,
      String structuredDataKey, ModifiableValueMap structuredDataProps) {
    this.variationDef = variationDef;
    this.structuredDataKey = structuredDataKey;
    this.structuredDataProps = structuredDataProps;
  }

  @Override
  public String getName() {
    return variationDef.getName();
  }

  @Override
  public String getDescription() {
    return variationDef.getDescription();
  }

  @Override
  public String getTitle() {
    return variationDef.getTitle();
  }

  @Override
  public String getContent() {
    return MockContentFragment_ContentElement_Structured.getContent(structuredDataKey, structuredDataProps);
  }

  @Override
  public void setContent(String content, String mimeType) throws ContentFragmentException {
    MockContentFragment_ContentElement_Structured.setContent(structuredDataKey, structuredDataProps, content);
  }

  @Override
  public String getContentType() {
    return null;
  }


  // --- unsupported operations ---

  @Override
  public void synchronize() throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  @Override
  public SyncStatus getSyncStatus() {
    throw new UnsupportedOperationException();
  }

  @Override
  public void setTitle(String title) throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  @Override
  public void setDescription(String description) throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  @Override
  public FragmentData getValue() {
    throw new UnsupportedOperationException();
  }

  @Override
  public void setValue(FragmentData arg0) throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  // latest AEM Cloud API
  public @NotNull Calendar getCreated() {
    throw new UnsupportedOperationException();
  }

}

==> io.wcm.testing.aem-mock.core-5.6.2-sources.jar: io/wcm/testing/mock/aem/MockContentFragment_ContentVariation_Structured.java <==
/*
 * #%L
 * wcm.io
 * %%
 * Copyright (C) 2019 wcm.io
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package io.wcm.testing.mock.aem;

import java.util.Calendar;
import java.util.Iterator;

import org.apache.sling.api.resource.ModifiableValueMap;
import org.jetbrains.annotations.NotNull;

import com.adobe.cq.dam.cfm.ContentFragmentException;
import com.adobe.cq.dam.cfm.ContentVariation;
import com.adobe.cq.dam.cfm.FragmentData;
import com.adobe.cq.dam.cfm.SyncStatus;
import com.adobe.cq.dam.cfm.VariationDef;
import com.adobe.cq.dam.cfm.VersionDef;
import com.adobe.cq.dam.cfm.VersionedContent;

/**
 * Mock implementation of {@link ContentVariation}.
 */
class MockContentFragment_ContentVariation_Structured implements ContentVariation {

  private final VariationDef variationDef;
  private final String structuredDataKey;
  private final ModifiableValueMap structuredDataProps;

  MockContentFragment_ContentVariation_Structured(VariationDef variationDef,
      String structuredDataKey, ModifiableValueMap structuredDataProps) {
    this.variationDef = variationDef;
    this.structuredDataKey = structuredDataKey;
    this.structuredDataProps = structuredDataProps;
  }

  @Override
  public String getName() {
    return variationDef.getName();
  }

  @Override
  public String getDescription() {
    return variationDef.getDescription();
  }

  @Override
  public String getTitle() {
    return variationDef.getTitle();
  }

  @Override
  public String getContent() {
    return MockContentFragment_ContentElement_Structured.getContent(structuredDataKey, structuredDataProps);
  }

  @Override
  public void setContent(String content, String mimeType) throws ContentFragmentException {
    MockContentFragment_ContentElement_Structured.setContent(structuredDataKey, structuredDataProps, content);
  }

  @Override
  public String getContentType() {
    return null;
  }


  // --- unsupported operations ---

  @Override
  public void synchronize() throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  @Override
  public SyncStatus getSyncStatus() {
    throw new UnsupportedOperationException();
  }

  @Override
  public void setTitle(String title) throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  @Override
  public void setDescription(String description) throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  @Override
  public FragmentData getValue() {
    throw new UnsupportedOperationException();
  }

  @Override
  public void setValue(FragmentData arg0) throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  // latest AEM Cloud API
  @Override
  public @NotNull Calendar getCreated() {
    throw new UnsupportedOperationException();
  }

  @Override
  public VersionDef createVersion(String label, String comment) throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  @Override
  public VersionedContent getVersionedContent(VersionDef version) throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  @Override
  public Iterator<VersionDef> listVersions() throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

  // latest AEM Cloud API
  @SuppressWarnings("unused")
  public ContentVariation getVersion(VersionDef versionDef) throws ContentFragmentException {
    throw new UnsupportedOperationException();
  }

}
